==> ltda-5.0.3.dev20211027+99-py3-none-any.whl: ltda/ltda_config.py <==
import os

# Time between CDB/CAF polls from archiver process in seconds
POLL_PERIOD_ARCHIVER = 120

# Time between CDB/CAF polls from restorer process in seconds
#POLL_PERIOD_RESTORER = 120
POLL_PERIOD_RESTORER = 120

# Active debug logging, True of False
DEBUGLOG = True

# LTDA install dir
#LTDA_INSTALL = "/opt/LTDA"

# Hibernate configuration script path
HIBERNATE_CFG_PATH = 'CDBAPI/etc/hibernate.cfg.xml'

# Path to the CAF shell scripts
#CAF_SCRIPTS_DIR = "/opt/Archive/bin"

# Directories where to write logs when no path is given as arg
#ARCHIVER_LOG_DIR = LTDA_INSTALL + "/log/archiver"
#RESTORER_LOG_DIR = LTDA_INSTALL + "/log/restorer"

# Where to store XML files
#XML_DIR = LTDA_INSTALL + "/xml"
# Where to store metadata XML files
#METADATA_DIR = "/tmp/LTDA"
#METADATA_DIR = "/storage/pmaster11/archive_buffer/metadata/LTDA"
# Pattern for naming products metadata files
#METADATA_PROD_PATTERN = "Product_%s.xml"
# Pattern for naming calibrations metadata files
#METADATA_CALIB_PATTERN = "CalibrationData_%s.xml"
# Whether to delete or not the metadata file after ticket completion
#METADATA_DELETE = True

# Log pattern determining the log line format
# Warning: changing pattern may require changes in Logger class!
LOG_PATTERN = "%s\t%s\t%s"

# How to write time in log
# Warning: changing pattern may require changes in Logger class!
LOG_TIME_PATTERN = "%04d/%02d/%02d-%02d:%02d:%02d"

# Number of days between each new log file creation
LOG_CHANGE_PERIOD = 1

# Filter list for dashboard logging
LOG_DASHBOARD_FILTER = [ "(reason: ticket lost), setting it to archive status 'ToBeArchived' again", 
                         "(reason: ticket lost), setting it to archive status 'ToBeRestored' again", 
                         "(reason: never archived), setting it to archive status 'NotArchived' again",
                         "(reason: unknown archive ticket",
                         "waivering unknown ticket" ]

# Old log files age for obsolescence (in days)
#OLDLOG_OBSOLESCENCE = 7

# Log file naming patterns. The first %s is the name of the log file (i.e. "Archiver" or "Restorer").
LOGFILE_PATTERN = "%s.log"

# Each %d is a part of a date + time.
OLDLOGFILE_PATTERN = "%s_%04d%02d%02d%02d%02d%02d.log"

# Log levels names
LOG_INFO = "INFO"
LOG_WARNING = "WARNING"
LOG_ERROR = "ERROR"
LOG_DEBUG = "DEBUG"

# Default FTP servers
DEFAULT_PROD_ARCH_FTP = "ftp://probadev:probad3v@pmtfs4.intern.vgt.vito.be:21/pmtfs4/PROBAV-US/LTDA/ARCHIVE"
DEFAULT_CAL_ARCH_FTP = "ftp://probadev:probad3v@pmtfs4.intern.vgt.vito.be:21/pmtfs4/PROBAV-US/LTDA/ARCHIVE"
DEFAULT_PROD_REST_FTP = "ftp://probadev:probad3v@pmtfs4.intern.vgt.vito.be:21/pmtfs4/PROBAV-US/LTDA/RESTORE"
DEFAULT_CAL_REST_FTP = "ftp://probadev:probad3v@pmtfs4.intern.vgt.vito.be:21/pmtfs4/PROBAV-US/LTDA/RESTORE"




# Maximum number of ticket reposts when recieving an error for a ticket
MAX_CAF_REPOST = 5

# Maximum number of ticket processed by LTDA at the same time. Set 0 for no limit.
ARCHIVER_MAX_CAF_REQUESTS = 50
RESTORER_MAX_COMMVAULT_REQUESTS = 10

COMMVAULT_CLIENTNAME = "pmaster11"
COMMVAULT_BACKUPSETNAME = "PROBA_V_LTDA"
# commvault timeout period before logging warnings for a given ticket, in seconds.
COMMVAULT_TIMEOUT = 86400

#will be changed if on jenkinshost
RESTORE_CACHE_DIR = "/data/archive/restore_temp"
ARCHIVE_CACHE_DIR = "/data/archive/archive_temp"

# Program name for archiver
# Warning: must correspond to the archiver python module name!
ARCHIVER_PROG_NAME = "ltda_archiver"

# Program name for retriever
# Warning: must correspond to the restorer python module name!
RESTORER_PROG_NAME = "ltda_restorer"

# Maximum number of source files to pass to commvault resrtore
#GETOBJ_MAX_TICKETS = 500
RESTORE_MAX_FILES = 500


unittest = os.getenv('UNITTEST')
if unittest is not None:
    unittest=unittest.upper()
if unittest == 'TRUE':
    RESTORE_CACHE_DIR = "temp"
    ARCHIVE_CACHE_DIR = "temp"
else:
    #will be changed if on jenkinshost
    RESTORE_CACHE_DIR = "/data/archive/restore_temp"
    ARCHIVE_CACHE_DIR = "/data/archive/archive_temp"

==> ltda-5.1.0.dev20211210+1-py3-none-any.whl: ltda/ltda_config.py <==
import os
PROD_TYPE_SKIP_LST = ['PROBAV_L1A_ANTAR']


# Time between CDB/CAF polls from archiver process in seconds
POLL_PERIOD_ARCHIVER = 120

# Time between CDB/CAF polls from restorer process in seconds
#POLL_PERIOD_RESTORER = 120
POLL_PERIOD_RESTORER = 120

# Active debug logging, True of False
DEBUGLOG = True

# LTDA install dir
#LTDA_INSTALL = "/opt/LTDA"

# Hibernate configuration script path
HIBERNATE_CFG_PATH = 'CDBAPI/etc/hibernate.cfg.xml'

# Path to the CAF shell scripts
#CAF_SCRIPTS_DIR = "/opt/Archive/bin"

# Directories where to write logs when no path is given as arg
#ARCHIVER_LOG_DIR = LTDA_INSTALL + "/log/archiver"
#RESTORER_LOG_DIR = LTDA_INSTALL + "/log/restorer"

# Where to store XML files
#XML_DIR = LTDA_INSTALL + "/xml"
# Where to store metadata XML files
#METADATA_DIR = "/tmp/LTDA"
#METADATA_DIR = "/storage/pmaster11/archive_buffer/metadata/LTDA"
# Pattern for naming products metadata files
#METADATA_PROD_PATTERN = "Product_%s.xml"
# Pattern for naming calibrations metadata files
#METADATA_CALIB_PATTERN = "CalibrationData_%s.xml"
# Whether to delete or not the metadata file after ticket completion
#METADATA_DELETE = True

# Log pattern determining the log line format
# Warning: changing pattern may require changes in Logger class!
LOG_PATTERN = "%s\t%s\t%s"

# How to write time in log
# Warning: changing pattern may require changes in Logger class!
LOG_TIME_PATTERN = "%04d/%02d/%02d-%02d:%02d:%02d"

# Number of days between each new log file creation
LOG_CHANGE_PERIOD = 1

# Filter list for dashboard logging
LOG_DASHBOARD_FILTER = [ "(reason: ticket lost), setting it to archive status 'ToBeArchived' again", 
                         "(reason: ticket lost), setting it to archive status 'ToBeRestored' again", 
                         "(reason: never archived), setting it to archive status 'NotArchived' again",
                         "(reason: unknown archive ticket",
                         "waivering unknown ticket" ]

# Old log files age for obsolescence (in days)
#OLDLOG_OBSOLESCENCE = 7

# Log file naming patterns. The first %s is the name of the log file (i.e. "Archiver" or "Restorer").
LOGFILE_PATTERN = "%s.log"

# Each %d is a part of a date + time.
OLDLOGFILE_PATTERN = "%s_%04d%02d%02d%02d%02d%02d.log"

# Log levels names
LOG_INFO = "INFO"
LOG_WARNING = "WARNING"
LOG_ERROR = "ERROR"
LOG_DEBUG = "DEBUG"

# Default FTP servers
DEFAULT_PROD_REST_FTP = "ftp://probadev:probad3v@pmtfs4.intern.vgt.vito.be:21/pmtfs4/PROBAV-US/LTDA/RESTORE"




# Maximum number of ticket reposts when recieving an error for a ticket
MAX_CAF_REPOST = 5

# Maximum number of ticket processed by LTDA at the same time. Set 0 for no limit.
ARCHIVER_MAX_CAF_REQUESTS = 50
RESTORER_MAX_COMMVAULT_REQUESTS = 10

COMMVAULT_CLIENTNAME = "pmaster11"
COMMVAULT_BACKUPSETNAME = "PROBA_V_LTDA"
# commvault timeout period before logging warnings for a given ticket, in seconds.
COMMVAULT_TIMEOUT = 86400   # 86400 = 24 hours

#will be changed if on jenkinshost
#RESTORE_CACHE_DIR = "/storage/pmaster11/archive_buffer/restore_cache"
#ARCHIVE_CACHE_DIR = "/storage/pmaster11/archive_buffer/archive_cache"

# Program name for archiver
# Warning: must correspond to the archiver python module name!
ARCHIVER_PROG_NAME = "ltda_archiver"

# Program name for retriever
# Warning: must correspond to the restorer python module name!
RESTORER_PROG_NAME = "ltda_restorer"

# Maximum number of source files to pass to commvault restore
#GETOBJ_MAX_TICKETS = 500
RESTORE_MAX_FILES = 500


unittest = os.getenv('UNITTEST')
if unittest is not None:
    unittest=unittest.upper()
if unittest == 'TRUE':
    RESTORE_CACHE_DIR = "temp"
    ARCHIVE_CACHE_DIR = "temp"
else:
    #will be changed if on jenkinshost
    RESTORE_CACHE_DIR = "/storage/pmaster11/archive_buffer/restore_cache"
    ARCHIVE_CACHE_DIR = "/storage/pmaster11/archive_buffer/archive_cache"
